DurationPickerLocalizationsKo class

Inheritance

Properties

baseUnitHour → String
no setteroverride
baseUnitMillisecond → String
no setteroverride
baseUnitMinute → String
no setteroverride
baseUnitSecond → String
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryUnitHour → String
no setteroverride
secondaryUnitMillisecond → String
no setteroverride
secondaryUnitMinute → String
no setteroverride
secondaryUnitSecond → String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited