DurationPickerLocalizations class abstract

Implementers

Properties

baseUnitHour → String
no setter
baseUnitMillisecond → String
no setter
baseUnitMinute → String
no setter
baseUnitSecond → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryUnitHour → String
no setter
secondaryUnitMillisecond → String
no setter
secondaryUnitMinute → String
no setter
secondaryUnitSecond → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

of(BuildContext context) → DurationPickerLocalizations